##  Activating the Extension
Admins can activate the extension. Follow these steps:
  1. Go to the Optional Features and Early Access section in the administration area.
  2. Ensure that the AI Agent extension is activated.
  3. For SAP Suggestions in Your Landscape, choose Activate, then confirm your action.
